#define TK_ABORT                           1
#define TK_AFTER                           2
#define TK_AGG_FUNCTION                    3
#define TK_ALL                             4
#define TK_AND                             5
#define TK_AS                              6
#define TK_ASC                             7
#define TK_ATTACH                          8
#define TK_BEFORE                          9
#define TK_BEGIN                          10
#define TK_BETWEEN                        11
#define TK_BITAND                         12
#define TK_BITNOT                         13
#define TK_BITOR                          14
#define TK_BY                             15
#define TK_CASCADE                        16
#define TK_CASE                           17
#define TK_CHECK                          18
#define TK_CLUSTER                        19
#define TK_COLLATE                        20
#define TK_COLUMN                         21
#define TK_COMMA                          22
#define TK_COMMENT                        23
#define TK_COMMIT                         24
#define TK_CONCAT                         25
#define TK_CONFLICT                       26
#define TK_CONSTRAINT                     27
#define TK_COPY                           28
#define TK_CREATE                         29
#define TK_DATABASE                       30
#define TK_DEFAULT                        31
#define TK_DEFERRABLE                     32
#define TK_DEFERRED                       33
#define TK_DELETE                         34
#define TK_DELIMITERS                     35
#define TK_DESC                           36
#define TK_DETACH                         37
#define TK_DISTINCT                       38
#define TK_DOT                            39
#define TK_DROP                           40
#define TK_EACH                           41
#define TK_ELSE                           42
#define TK_END                            43
#define TK_END_OF_FILE                    44
#define TK_EQ                             45
#define TK_EXCEPT                         46
#define TK_EXPLAIN                        47
#define TK_FAIL                           48
#define TK_FLOAT                          49
#define TK_FOR                            50
#define TK_FOREIGN                        51
#define TK_FROM                           52
#define TK_FUNCTION                       53
#define TK_GE                             54
#define TK_GLOB                           55
#define TK_GROUP                          56
#define TK_GT                             57
#define TK_HAVING                         58
#define TK_ID                             59
#define TK_IGNORE                         60
#define TK_ILLEGAL                        61
#define TK_IMMEDIATE                      62
#define TK_IN                             63
#define TK_INDEX                          64
#define TK_INITIALLY                      65
#define TK_INSERT                         66
#define TK_INSTEAD                        67
#define TK_INTEGER                        68
#define TK_INTERSECT                      69
#define TK_INTO                           70
#define TK_IS                             71
#define TK_ISNULL                         72
#define TK_JOIN                           73
#define TK_JOIN_KW                        74
#define TK_KEY                            75
#define TK_LE                             76
#define TK_LIKE                           77
#define TK_LIMIT                          78
#define TK_LP                             79
#define TK_LSHIFT                         80
#define TK_LT                             81
#define TK_MATCH                          82
#define TK_MINUS                          83
#define TK_NE                             84
#define TK_NOT                            85
#define TK_NOTNULL                        86
#define TK_NULL                           87
#define TK_OF                             88
#define TK_OFFSET                         89
#define TK_ON                             90
#define TK_OR                             91
#define TK_ORDER                          92
#define TK_PLUS                           93
#define TK_PRAGMA                         94
#define TK_PRIMARY                        95
#define TK_RAISE                          96
#define TK_REFERENCES                     97
#define TK_REM                            98
#define TK_REPLACE                        99
#define TK_RESTRICT                       100
#define TK_ROLLBACK                       101
#define TK_ROW                            102
#define TK_RP                             103
#define TK_RSHIFT                         104
#define TK_SELECT                         105
#define TK_SEMI                           106
#define TK_SET                            107
#define TK_SLASH                          108
#define TK_SPACE                          109
#define TK_STAR                           110
#define TK_STATEMENT                      111
#define TK_STRING                         112
#define TK_TABLE                          113
#define TK_TEMP                           114
#define TK_THEN                           115
#define TK_TRANSACTION                    116
#define TK_TRIGGER                        117
#define TK_UMINUS                         118
#define TK_UNCLOSED_STRING                119
#define TK_UNION                          120
#define TK_UNIQUE                         121
#define TK_UPDATE                         122
#define TK_UPLUS                          123
#define TK_USING                          124
#define TK_VACUUM                         125
#define TK_VALUES                         126
#define TK_VARIABLE                       127
#define TK_VIEW                           128
#define TK_WHEN                           129
#define TK_WHERE                          130
